#
# spec file for package python-glances
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-glances
Version:        3.1.0
Release:        bp155.2.12
Summary:        A curses-based monitoring tool
License:        LGPL-3.0-only
Group:          Development/Languages/Python
URL:            https://nicolargo.github.io/glances/
Source:         https://files.pythonhosted.org/packages/source/G/Glances/Glances-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
Requires:       python-curses
Requires:       python-psutil >= 2.0.0
Suggests:       hddtemp
Suggests:       python-batinfo
Suggests:       python-bottle
Suggests:       python-matplotlib
Suggests:       python-netifaces
Suggests:       python-py3sensors
Suggests:       python-pysnmp
Suggests:       python-zeroconf >= 0.16
Suggests:       sensors
Provides:       glances
BuildArch:      noarch
%python_subpackages

%description
Glances is a curses-based monitoring tool. Glances uses the PsUtil
library to get information from your system. It monitors CPU, load,
memory, network bandwidth, disk I/O, disk use, process.

%prep
%setup -q -n Glances-%{version}
#drop shebang
sed -i -e '/^#!\//, 1d' glances/__main__.py

%build
%python_build

%install
%python_install
install -d %{buildroot}%{_docdir}/%{name}
mv %{buildroot}/%{_datadir}/doc/glances %{buildroot}%{_docdir}/%{name}
install -Dm0644 conf/glances.conf %{buildroot}%{_sysconfdir}/glances/glances.conf
rm %{buildroot}/%{_docdir}/%{name}/glances -Rf
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license COPYING
%doc AUTHORS NEWS README.rst
%python3_only %{_bindir}/glances
%{_mandir}/man1/glances.1%{?ext_man}
%dir %{_sysconfdir}/glances
%config %{_sysconfdir}/glances/glances.conf
%{python_sitelib}/glances
%{python_sitelib}/Glances-*.egg-info

%changelog
* Sat Jan 19 2019 mardnh@gmx.de
- Update to version 3.1.0
  Enhancements and new features:
  * Add a CSV output format to the STDOUT output mode
  * Feature request: HDD S.M.A.R.T. reports
  * Sort docker
  * Prohibit some plug-in data from being exported to influxdb
  * Disable plugin from Glances configuration file
  * Curses-browser's server list paging added
  * Client Browser's thread management added
  Bugs corrected:
  * TypeError: '<' not supported between instances of 'float' and 'str'
  * GPU plugin not exported to influxdb
  * Crash after running fine for several hours
  * Timezone listed doesn’t match system timezone, outputs wrong time
  * Compare issue with Process.cpu_times()
  * ERROR -- Can not grab extended stats (invalid attr name 'num_fds')
  * Action on port/web plugins is not working
  * Support for monochrome (serial) terminals e.g. vt220
  * TypeError on opening (Wifi plugin)
  * Some field name are incorrect in CSV export
  * Standard output misbehaviour (need to flush)
  * Create an option to set the username to use in Web or RPC Server
    mode
  * Missing kernel task names when the webui is switched to long
    process names
  * Drive name with special characters causes crash
  * Cannot get stats in Cloud plugin
  Others:
  * Refactor Glances logs (now called Glances events)
  * "chart" extra dep replace by "graph"
* Mon Jan  7 2019 mardnh@gmx.de
- Adjust wildcard to match the egg-info in %%{python_sitelib}
* Sun Dec 16 2018 mardnh@gmx.de
- Specfile cleanup
- Switch to python3
- Update to version 3.0.2
  See https://github.com/nicolargo/glances/wiki/Glances-3.0-Release-Note
  for the full changelog.
* Sun Oct  1 2017 mardnh@gmx.de
- Update to version 2.11.1
  - Enhancements and new features:
  * New export plugin: standard and configurable Restfull exporter (issue #1129)
  * Add a JSON export module (issue #1130)
  * [WIP] Refactoring of the WebUI
  - Bugs corrected:
  * Installing GPU plugin crashes entire Glances (issue #1102)
  * Potential memory leak in Windows WebUI (issue #1056)
  * glances_network `OSError: [Errno 19] No such device` (issue #1106)
  * GPU plugin. <class 'TypeError'>: ... not JSON serializable"> (issue #1112)
  * PermissionError on macOS (issue #1120)
  * Cant move up or down in glances --browser (issue #1113)
  * Unable to give aliases to or hide network interfaces and disks (issue #1126)
  * `UnicodeDecodeError` on mountpoints with non-breaking spaces (issue #1128)
* Mon May 29 2017 mardnh@gmx.de
- Update to version 2.10
  - Enhancements and new features:
  * New plugin to scan remote Web sites (URL) (issue #981)
  * Add trends in the Curses interface (issue #1077)
  * Add new repeat function to the action (issue #952)
  * Use -> and <- arrows keys to switch between processing sort (issue #1075)
  * Refactor __init__ and main scripts (issue #1050)
  * [WebUI] Improve WebUI for Windows 10 (issue #1052)
  - Bugs corrected:
  * StatsD export prefix option is ignored (issue #1074)
  * Some FS and LAN metrics fail to export correctly to StatsD (issue #1068)
  * Problem with non breaking space in file system name (issue #1065)
  * TypeError: string indices must be integers (Network plugin) (issue #1054)
  * No Offline status for timeouted ports? (issue #1084)
  * When exporting, uptime values loop after 1 day (issue #1092)
* Sat Apr  1 2017 mardnh@gmx.de
- Update to version 2.9.1
  * Glances PerCPU issues with Curses UI on Android (issue #1071)
  * Remove extra } in format string (issue #1073)
* Mon Mar 27 2017 mardnh@gmx.de
- Update to version 2.9.0
  - Enhancements and new features:
  * Add a Prometheus export module (issue #930)
  * Add a Kafka export module (issue #858)
  * Port in the -c URI (-c hostname:port) (issue #996)
  - Bugs corrected:
  * On Windows --export-statsd terminates immediately and does not export (issue #1067)
  * Glances v2.8.7 issues with Curses UI on Android (issue #1053)
  * Fails to start, OSError in sensors_temperatures (issue #1057)
  * Crashs after long time running the glances --browser (issue #1059)
  * Sensor values don't refresh since psutil backend (issue #1061)
  * glances-version.db Permission denied (issue #1066)
* Mon Feb 13 2017 mardnh@gmx.de
- Update to version 2.8.1
  - Changes:
  * Enable docker plugin on Windows (issue #1009) - Thanks to @fraoustin
  - Bugs corrected:
  * Glances export issue with CPU and SENSORS (issue #1024)
  * Can't export data to a CSV file in Client/Server mode (issue #1023)
  * Autodiscover error while binding on IPv6 addresses (issue #1002)
  * GPU plugin is display when hitting '4' or '5' shortkeys (issue #1012)
  * Interrupts and usb_fiq (issue #1007)
  * Docker image does not work in web server mode! (issue #1017)
  * IRQ plugin is not display anymore (issue #1013)
  * Autodiscover error while binding on IPv6 addresses (issue #1002)
* Sat Jan 21 2017 mardnh@gmx.de
- Update to version 2.8
  - Changes:
  * The curses interface on Windows is no more. The web-based interface is now
    the default. (issue #946)
  * The name of the log file now contains the name of the current user logged in,
    i.e., 'glances-USERNAME.log'.
  * IRQ plugin off by default. '--disable-irq' option replaced by '--enable-irq'.
  - Enhancements and new features:
  * GPU monitoring (limited to NVidia) (issue #170)
  * WebUI CPU consumption optimization (issue #836)
  * Not compatible with the new Docker API 2.0 (Docker 1.13) (issue #1000)
  * Add ZeroMQ exporter (issue #939)
  * Add CouchDB exporter (issue #928)
  * Add hotspot Wifi informations (issue #937)
  * Add default interface speed and automatic rate thresolds (issue #718)
  * Highlight max stats in the processes list (issue #878)
  * Docker alerts and actions (issue #875)
  * Glances API returns the processes PPID (issue #926)
  * Configure server cached time from the command line --cached-time (issue #901)
  * Make the log logger configurable (issue #900)
  * System uptime in export (issue #890)
  * Refactor the --disable-* options (issue #948)
  * PID column too small if kernel.pid_max is > 99999 (issue #959)
  - Bugs corrected:
  * Glances RAID plugin Traceback (issue #927)
  * Default AMP crashes when 'command' given (issue #933)
  * Default AMP ignores `enable` setting (issue #932)
  * /proc/interrupts not found in an OpenVZ container (issue #947)
* Sun Oct  9 2016 mardnh@gmx.de
- Update to version 2.7.1
  - Bugs corrected:
  * AMP plugin crashs on start with Python 3 (issue #917)
  * Ports plugin crashs on start with Python 3 (issue #918)
* Sat Sep 10 2016 mardnh@gmx.de
- Minor specfile fixes
- Update to version 2.7
  - Backward-incompatible changes:
  * Drop support for Python 2.6 (issue #300)
  - Deprecated:
  * Monitoring process list module is replaced by AMP (see issue #780)
  * Use --export-graph instead of --enable-history (issue #696)
  * Use --path-graph instead of --path-history (issue #696)
  - Enhancements and new features:
  * Add Application Monitoring Process plugin (issue #780)
  * Add a new "Ports scanner" plugin (issue #734)
  * Add a new IRQ monitoring plugin (issue #911)
  * Improve IP plugin to display public IP address (issue #646)
  * CPU additionnal stats monitoring: Context switch, Interrupts... (issue #810)
  * Filter processes by others stats (username) (issue #748)
  * [Folders] Differentiate permission issue and non-existence of a directory (issue #828)
  * [Web UI] Add cpu name in quicklook plugin (issue #825)
  * Allow theme to be set in configuration file (issue #862)
  * Display a warning message when Glances is outdated (issue #865)
  * Refactor stats history and export to graph. History available through API (issue #696)
  * Add Cassandra/Scylla export plugin (issue #857)
  * Huge pull request by Nicolas Hart to optimize the WebUI (issue #906)
  * Improve documentation: http://glances.readthedocs.io (issue #872)
  - Bugs corrected:
  * Crash on launch when viewing temperature of laptop HDD in sleep mode (issue #824)
  * [Web UI] Fix folders plugin never displayed (issue #829)
  * Correct issue IP plugin: VPN with no internet access (issue #842)
  * Idle process is back on FreeBSD and Windows (issue #844)
  * On Windows, Glances try to display unexisting Load stats (issue #871)
  * Check CPU info (issue #881)
  * Unicode error on processlist on Windows server 2008 (french) (issue #886)
  * PermissionError/OSError when starting glances (issue #885)
  * Zeroconf problem with zeroconf_type = "_%%s._tcp." %% __appname__ (issue #888)
  * Zeroconf problem with zeroconf service name (issue #889)
  * [WebUI] Glances will not get past loading screen - Windows OS (issue #815)
  * Improper bytes/unicode in glances_hddtemp.py (issue #887)
  * Top 3 processes are back in the alert summary
* Wed Jun 29 2016 rmaliska@suse.com
- Updated to version 2.6.2
  * fixed crash with Docker 1.11
* Sat Mar 26 2016 mardnh@gmx.de
- Update to version 2.6.1
  - Enhancements and new features:
  * Add a connector to Riemann (issue #822 by Greogo Nagy)
  - Bugs corrected:
  * Browsing for servers which are in the [serverlist] is broken (issue #819)
  * [WebUI] Glances will not get past loading screen (issue #815) opened 9 days ago
  * Python error after upgrading from 2.5.1 to 2.6 bug (issue #813)
- Update to version 2.6.0
  - Enhancements and new features:
  * Add a connector to ElasticSearch (welcome to Kibana dashboard) (issue #311)
  * New folders' monitoring plugins (issue #721)
  * Use wildcard (regexp) to the hide configuration option for network, diskio and fs sections (issue #799 )
  * Command line arguments are now take into account in the WebUI (#789 by  @notFloran)
  * Change username for server and web server authentication (issue #693)
  * Add an option to disable top menu (issue #766)
  * Add IOps in the DiskIO plugin (issue #763)
  * Add hide configuration key for FS Plugin (issue #736)
  * Add process summary min/max stats (issue #703)
  * Add timestamp to the CSV export module (issue #708)
  * Add a shortcut 'E' to delete process filter (issue #699)
  * By default, hide disk I/O ram1-** (issue #714)
  * When Glances is starting the notifications should be delayed (issue #732)
  * Add option (--disable-bg) to disable ANSI background colours (issue #738 by okdana)
  * [WebUI] add "pointer" cursor for sortable columns (issue #704 by @notFloran)
  * [WebUI] Make web page title configurable (issue #724)
  * Do not show interface in down state (issue #765)
  * InfluxDB > 0.9.3 needs float and not int for numerical value (issue#749 and issue#750 by nicolargo)
- Bugs corrected:
  * Can't read sensors on a Thinkpad (issue #711)
  * InfluxDB/OpenTSDB: tag parsing broken (issue #713)
  * Grafana Dashboard outdated for InfluxDB 0.9.x (issue #648)
  * '--tree' breaks process filter on Debian 8 (issue #768)
  * Fix highlighting of process when it contains whitespaces (issue #546 by Alessio Sergi)
  * Fix RAID support in Python 3 (issue #793 by Alessio Sergi)
  * Use dict view objects to avoid issue (issue #758 by Alessio Sergi)
  * System exit if Cpu not supported by the Cpuinfo lib (issue #754 by nicolargo)
  * KeyError: 'cpucore' when exporting data to InfluxDB (issue #729) by nicolargo)
* Sun Dec 13 2015 mardnh@gmx.de
- Update to version 2.5.1
  - Bugs corrected:
  * Unable to unlock password protected servers in browser mode bug (issue #694)
  * Correct issue when Glances is started in console on Windows OS
  * [WebUI] when alert is ongoing hide level enhancement (issue #692)
* Tue Oct  6 2015 mardnh@gmx.de
- Update to version 2.5
  - new features
  * Allow export of Docker and sensors plugins stats to InfluxDB, StatsD... (issue #600)
  * Docker plugin shows IO and network bitrate (issue #520)
  * Server password configuration for the browser mode (issue #500)
  * Add support for OpenTSDB export (issue #638)
  * Add additional stats (iowait, steal) to the perCPU plugin (issue #672)
  * Support Fahrenheit unit in the sensor plugin using the --fahrenheit command line option (issue #620)
  * When a process filter is set, display sum of CPU, MEM... (issue #681)
  * Improve the QuickLookplugin by adding hardware CPU info (issue #673)
  * WebUI display a message if server is not available (issue #564)
  * Display an error if export is not used in the standalone/client mode (issue #614)
  * New --disable-quicklook, --disable-cpu, --disable-mem, --disable-swap, --disable-load tags (issue #631)
  * Complete refactoring of the WebUI thanks to the (awesome) Floran pull (issue #656)
  * Network cumulative /combination feature available in the WebUI (issue #552)
  * IRIX mode off implementation (issue#628)
  * Short process name displays arguments (issue #609)
  * Server password configuration for the browser mode (issue #500)
  * Display an error if export is not used in the standalone/client mode (issue #614)
  - Bugs corrected:
  * The WebUI displays bad sensors stats (issue #632)
  * Filter processes crashs with a bad regular expression pattern (issue #665)
  * Error with IP plugin (issue #651)
  * Crach with Docker plugin (issue #649)
  * Docker plugin crashs with webserver mode (issue #654)
  * Infrequently crashing due to assert (issue #623)
  * Value for free disk space is counterintuative on ext file systems (issue #644)
  * Try/catch for unexpected psutil.NoSuchProcess: process no longer exists (issue #432)
  * Fatal error using Python 3.4 and Docker plugin bug (issue #602)
  * Add missing new line before g man option (issue #595)
  * Remove unnecessary type="text/css" for link (HTML5) (issue #595)
  * Correct server mode issue when no network interface is available (issue #528)
  * Avoid crach on olds kernels (issue #554)
  * Avoid crashing if LC_ALL is not defined by user (issue #517)
  * Add a disable HDD temperature option on the command line (issue #515)
* Sat Dec 20 2014 mardnh@gmx.de
- initial package
